pub struct SetMultipleResponseHeadersLayer<M> { /* private fields */ }Expand description
Layer that applies SetMultipleResponseHeader which adds multiple response headers.
See SetMultipleResponseHeader for more details.
Implementations
Sourceimpl<M> SetMultipleResponseHeadersLayer<M>
impl<M> SetMultipleResponseHeadersLayer<M>
Sourcepub fn overriding(
metadata: Vec<HeaderMetadata<M>>,
) -> SetMultipleResponseHeadersLayer<M>
pub fn overriding( metadata: Vec<HeaderMetadata<M>>, ) -> SetMultipleResponseHeadersLayer<M>
Create a new SetMultipleResponseHeadersLayer that overrides any existing values for the same header.
If any previous value exists for the same header, it is removed and replaced with the new matching header value.
Sourcepub fn appending(
metadata: Vec<HeaderMetadata<M>>,
) -> SetMultipleResponseHeadersLayer<M>
pub fn appending( metadata: Vec<HeaderMetadata<M>>, ) -> SetMultipleResponseHeadersLayer<M>
Create a new SetMultipleResponseHeadersLayer that appends header values.
The new header is always added, preserving any existing values. If previous values exist, the header will have multiple values.
Sourcepub fn if_not_present(
metadata: Vec<HeaderMetadata<M>>,
) -> SetMultipleResponseHeadersLayer<M>
pub fn if_not_present( metadata: Vec<HeaderMetadata<M>>, ) -> SetMultipleResponseHeadersLayer<M>
Create a new SetMultipleResponseHeadersLayer that only inserts if the header is not already present.
If a previous value exists for the header, the new value is not inserted.